<?php
/**
 * @file
 * Contains \Drupal\thermometer\Plugin\Block\Thermometer.
 */

namespace Drupal\thermometer\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a 'Thermometer' block.
 *
 * @Block(
 *  id = "thermometer_block",
 *  admin_label = @Translation("Progress Thermometer"),
 * )
 */
class Thermometer extends BlockBase {

  /**
   * {@inheritdoc}
   */
  public function build() {
    $block = array();

    $config = $this->getConfiguration();

    $progress = isset($config['progress']) ? $config['progress'] : THERMOMETER_PROGRESS_DEFAULT;
    $goal = isset($config['goal']) ? $config['goal'] : THERMOMETER_GOAL_DEFAULT;
    $button_text = isset($config['button_text']) ? $config['button_text'] : THERMOMETER_BUTTON_TEXT_DEFAULT;
    $button_url = isset($config['button_url']) ? $config['button_url'] : THERMOMETER_BUTTON_URL_DEFAULT;
    $button_window = isset($config['button_window']) ? $config['button_window'] : THERMOMETER_BUTTON_WINDOW_DEFAULT;

    $block['thermometer_widget'] = array(
      '#theme' => 'thermometer_widget',
      '#progress' => $progress,
      '#goal' => $goal,
      '#button_text' => $button_text,
      '#button_url' => $button_url,
      '#button_window' => $button_window,
      '#attached' => array(
        'library' => array(
          'thermometer/thermometer_lib',
        ),
      ),
    );

    return $block;
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $form = parent::blockForm($form, $form_state);

    // Retrieve existing configuration for this block.
    $config = $this->getConfiguration();

    $form['thermometer_progress'] = array(
      '#type' => 'textfield',
      '#title' => t('Progress so far'),
      '#default_value' => isset($config['progress']) ? $config['progress'] : THERMOMETER_PROGRESS_DEFAULT,
      '#element_validate' => array(array('Drupal\Core\Render\Element\Number', 'validateNumber')),
    );
    $form['thermometer_goal'] = array(
      '#type' => 'textfield',
      '#title' => t('Goal'),
      '#default_value' => isset($config['goal']) ? $config['goal'] : THERMOMETER_GOAL_DEFAULT,
      '#element_validate' => array(array('Drupal\Core\Render\Element\Number', 'validateNumber')),
    );
    $form['thermometer_button_text'] = array(
      '#type' => 'textfield',
      '#title' => t('Button Text'),
      '#description' => t('Text for the donate button. Leave blank to not show a donate button.'),
      '#default_value' => isset($config['button_text']) ? $config['button_text'] : THERMOMETER_BUTTON_TEXT_DEFAULT,
    );
    $form['thermometer_button_url'] = array(
      '#type' => 'textfield',
      '#title' => t('Button URL'),
      '#description' => t('URL to page where people can donate'),
      '#default_value' => isset($config['button_url']) ? $config['button_url'] : THERMOMETER_BUTTON_URL_DEFAULT,
      '#element_validate' => array(array('Drupal\Core\Render\Element\Url', 'validateUrl')),
    );
    $form['thermometer_button_window'] = array(
      '#type' => 'checkbox',
      '#title' => t('Open in new window'),
      '#description' => t('Enable to open the donate button url in a new window'),
      '#default_value' => isset($config['button_window']) ? $config['button_window'] : THERMOMETER_BUTTON_WINDOW_DEFAULT,
    );

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    // Save our custom settings when the form is submitted.
    $this->setConfigurationValue('progress', $form_state->getValue('thermometer_progress'));
    $this->setConfigurationValue('goal', $form_state->getValue('thermometer_goal'));
    $this->setConfigurationValue('button_text', $form_state->getValue('thermometer_button_text'));
    $this->setConfigurationValue('button_url', $form_state->getValue('thermometer_button_url'));
    $this->setConfigurationValue('button_window', $form_state->getValue('thermometer_button_window'));
  }

}
